<?php
/*
Plugin Name: Display File Sizes
Plugin URI: http://wordpress.org/extend/plugins/display-file-sizes
Description: Shows file sizes for attachments on the attachment edit screen.
Version: 1.0
Author: desrosj
Author URI: http://jonathandesrosiers.com
License: GPLv2 or later
*/

class Display_File_Sizes {

	/**
	 * __construct function.
	 *
	 * @access public
	 * @return void
	 */
	function __construct() {
		add_action( 'attachment_submitbox_misc_actions', array( $this, 'attachment_submitbox_misc_actions' ), 20 );
	}

	/**
	 * Display the file size on the attachment edit screen.
	 *
	 * @access public
	 * @return void
	 */
	function attachment_submitbox_misc_actions() {
		global $post, $_wp_additional_image_sizes;

		if ( $original = get_attached_file( $post->ID ) ) : ?>
			<div class="misc-pub-section file-size">
				<span>File Size: <strong><?php echo $this->get_file_size( $original ); ?></strong></span>
			</div>
			<?php
		endif;
	}

	/**
	 * Returns the file size of the given URL.
	 *
	 * @access public
	 * @param string $image_url (default: '')
	 * @return void
	 */
	function get_file_size( $file_url = '' ) {
		if ( empty( $file_url ) )
			return;

		$sizes = apply_filters( 'dfs_size_types', array( 'Bytes', 'KB', 'MB', 'GB' ) );
		$file_size = filesize( esc_url( $file_url ) );

		return round( $file_size / pow( 1024, ( $i = floor( log( $file_size, 1024 ) ) ) ) ) . ' ' . $sizes[ $i ];
	}
}
$display_file_sizes = new Display_File_Sizes();